// SPDX-FileCopyrightText: Matteo Settenvini <matteo.settenvini@montecristosoftware.eu>
// SPDX-License-Identifier: EUPL-1.2

use super::Cleaner;
use crate::decision::{Action, Decision};
use anyhow::Result;
use async_trait::async_trait;
use std::path::PathBuf;
use tokio::sync::{broadcast, mpsc};

/// Cleans up unused shared libraries
/// and warns about broken dependencies as well
pub struct Dso {}

impl Dso {
    pub fn new() -> Self {
        Self {}
    }
}

#[async_trait]
impl Cleaner for Dso {
    async fn run(
        &mut self,
        mut files: broadcast::Receiver<PathBuf>,
        decisions: mpsc::Sender<Decision>,
    ) -> Result<()> {
        while let Ok(file) = files.recv().await {
            // TODO: handle Lagged?
            decisions
                .send(Decision {
                    path: file,
                    action: Action::Remove,
                })
                .await?;
        }

        Ok(())
    }
}
