// SPDX-FileCopyrightText: Matteo Settenvini <matteo.settenvini@montecristosoftware.eu>
// SPDX-License-Identifier: EUPL-1.2

mod args;
mod cleaners;
mod decision;

use anyhow::Result;
use args::Args;
use clap::Parser as _;
use cleaners::Runner;
use env_logger::Env;

#[tokio::main]
async fn main() -> Result<()> {
    let logging_env = Env::default().filter_or("LOG_LEVEL", "warn");
    env_logger::Builder::from_env(logging_env).init();

    let args = Args::try_parse()?;
    std::env::set_current_dir(&args.sysroot_location)?;

    let runner = Runner::new(args);
    runner.run().await?;
    Ok(())
}
